@@ -19,8 +19,9 @@ import getpass
 import functools
 import dataclasses
 import importlib.metadata
-from typing import (Mapping, Optional, Sequence, Tuple, ClassVar, Dict, Any,
+from typing import (Optional, ClassVar, Any,
                     TYPE_CHECKING)
+from collections.abc import Mapping, Sequence
 
 from qutebrowser.qt import machinery
 from qutebrowser.qt.core import PYQT_VERSION_STR
@@ -43,7 +44,7 @@ except ImportError:  # pragma: no cover
 import qutebrowser
 from qutebrowser.utils import (log, utils, standarddir, usertypes, message, resources,
                                qtutils)
-from qutebrowser.misc import objects, earlyinit, sql, httpclient, pastebin, elf
+from qutebrowser.misc import objects, earlyinit, sql, httpclient, pastebin, elf, wmname
 from qutebrowser.browser import pdfjs
 from qutebrowser.config import config
 if TYPE_CHECKING:
@@ -105,7 +106,7 @@ class Distribution(enum.Enum):
     solus = enum.auto()
 
 
-def _parse_os_release() -> Optional[Dict[str, str]]:
+def _parse_os_release() -> Optional[dict[str, str]]:
     """Parse an /etc/os-release file."""
     filename = os.environ.get('QUTE_FAKE_OS_RELEASE', '/etc/os-release')
     info = {}
@@ -250,7 +251,7 @@ def _git_str_subprocess(gitpath: str) -> Optional[str]:
         return None
 
 
-def _release_info() -> Sequence[Tuple[str, str]]:
+def _release_info() -> Sequence[tuple[str, str]]:
     """Try to gather distribution release information.
 
     Return:
@@ -321,8 +322,8 @@ class ModuleInfo:
         except (ImportError, ValueError):
             self._installed = False
             return
-        else:
-            self._installed = True
+
+        self._installed = True
 
         for attribute_name in self._version_attributes:
             if hasattr(module, attribute_name):
@@ -331,6 +332,13 @@ class ModuleInfo:
                 self._version = str(version)
                 break
 
+        if self._version is None:
+            try:
+                self._version = importlib.metadata.version(self.name)
+            except importlib.metadata.PackageNotFoundError:
+                log.misc.debug(f"{self.name} not found")
+                self._version = None
+
         self._initialized = True
 
     def get_version(self) -> Optional[str]:
@@ -371,7 +379,7 @@ class ModuleInfo:
 
         version = self.get_version()
         if version is None:
-            return f'{self.name}: yes'
+            return f'{self.name}: unknown'
 
         text = f'{self.name}: {version}'
         if self.is_outdated():
@@ -379,10 +387,10 @@ class ModuleInfo:
         return text
 
 
-def _create_module_info() -> Dict[str, ModuleInfo]:
+def _create_module_info() -> dict[str, ModuleInfo]:
     packages = [
         ('colorama', ['VERSION', '__version__']),
-        ('jinja2', ['__version__']),
+        ('jinja2', []),
         ('pygments', ['__version__']),
         ('yaml', ['__version__']),
         ('adblock', ['__version__'], "0.3.2"),
@@ -486,7 +494,7 @@ def _pdfjs_version() -> str:
     else:
         pdfjs_file = pdfjs_file.decode('utf-8')
         version_re = re.compile(
-            r"""^ *(PDFJS\.version|(var|const) pdfjsVersion) = ['"](?P<version>[^'"]+)['"];$""",
+            r"""^ *(PDFJS\.version|(var|const|\*) pdfjsVersion) = ['"]?(?P<version>[^'"\n]+)['"]?;?$""",
             re.MULTILINE)
 
         match = version_re.search(pdfjs_file)
@@ -538,20 +546,24 @@ class WebEngineVersions:
     chromium_security: Optional[str] = None
     chromium_major: Optional[int] = dataclasses.field(init=False)
 
-    _BASES: ClassVar[Dict[int, str]] = {
-        83: '83.0.4103.122',  # ~2020-06-24
-        87: '87.0.4280.144',  # ~2020-12-02
-        90: '90.0.4430.228',  # 2021-06-22
-        94: '94.0.4606.126',  # 2021-11-17
-        102: '102.0.5005.177',  # ~2022-05-24
+    # Dates based on https://chromium.googlesource.com/chromium/src/+refs
+    _BASES: ClassVar[dict[int, str]] = {
+        83: '83.0.4103.122',  # 2020-06-27, Qt 5.15.2
+        87: '87.0.4280.144',  # 2021-01-08, Qt 5.15
+        90: '90.0.4430.228',  # 2021-06-22, Qt 6.2
+        94: '94.0.4606.126',  # 2021-11-17, Qt 6.3
+        102: '102.0.5005.177',  # 2022-09-01, Qt 6.4
         # (.220 claimed by code, .181 claimed by CHROMIUM_VERSION)
-        108: '108.0.5359.220',  # ~2022-12-23
-        112: '112.0.5615.213',  # ~2023-04-18
-        118: '118.0.5993.220',  # ~2023-10-24
-        # 122: '122.?.????.???',  # ~2024-??-??
+        108: '108.0.5359.220',  # 2023-01-27, Qt 6.5
+        112: '112.0.5615.213',  # 2023-05-24, Qt 6.6
+        118: '118.0.5993.220',  # 2024-01-25, Qt 6.7
+        122: '122.0.6261.171',  # 2024-04-15, Qt 6.8
+        130: '130.0.6723.192',  # 2025-01-06, Qt 6.9
+        134: '134.0.6998.208',  # 2025-04-16, Qt 6.10
     }
 
-    _CHROMIUM_VERSIONS: ClassVar[Dict[utils.VersionNumber, Tuple[str, Optional[str]]]] = {
+    # Dates based on https://chromereleases.googleblog.com/
+    _CHROMIUM_VERSIONS: ClassVar[dict[utils.VersionNumber, tuple[str, Optional[str]]]] = {
         # ====== UNSUPPORTED =====
 
         # Qt 5.12: Chromium 69
@@ -589,6 +601,8 @@ class WebEngineVersions:
         # 5.15.15: unknown security fixes
         utils.VersionNumber(5, 15, 16): (_BASES[87], '119.0.6045.123'),  # 2023-11-07
         utils.VersionNumber(5, 15, 17): (_BASES[87], '123.0.6312.58'),  # 2024-03-19
+        utils.VersionNumber(5, 15, 18): (_BASES[87], '130.0.6723.59'),  # 2024-10-14
+        utils.VersionNumber(5, 15, 19): (_BASES[87], '135.0.7049.95'),  # 2025-04-14
 
 
         ## Qt 6.2
@@ -626,11 +640,24 @@ class WebEngineVersions:
 
         ## Qt 6.7
         utils.VersionNumber(6, 7): (_BASES[118], '122.0.6261.128'),  # 2024-03-12
-        utils.VersionNumber(6, 7, 1): (_BASES[118], '124.0.6367.202'),  # ~2024-05-09
+        utils.VersionNumber(6, 7, 1): (_BASES[118], '124.0.6367.202'),  # 2024-05-09
         utils.VersionNumber(6, 7, 2): (_BASES[118], '125.0.6422.142'),  # 2024-05-30
+        utils.VersionNumber(6, 7, 3): (_BASES[118], '129.0.6668.58'),  # 2024-09-17
 
         ## Qt 6.8
-        # utils.VersionNumber(6, 8): (_BASES[122], '???'),  # 2024-03-12
+        utils.VersionNumber(6, 8): (_BASES[122], '129.0.6668.70'),  # 2024-09-24
+        utils.VersionNumber(6, 8, 1): (_BASES[122], '131.0.6778.70'),  # 2024-11-12
+        utils.VersionNumber(6, 8, 2): (_BASES[122], '132.0.6834.111'),  # 2025-01-22
+        utils.VersionNumber(6, 8, 3): (_BASES[122], '134.0.6998.89'),  # 2025-03-10
+
+        ## Qt 6.9
+        utils.VersionNumber(6, 9): (_BASES[130], '133.0.6943.141'),  # 2025-02-25
+        utils.VersionNumber(6, 9, 1): (_BASES[130], '136.0.7103.114'),  # 2025-05-13
+        utils.VersionNumber(6, 9, 2): (_BASES[130], '139.0.7258.67'),  # 2025-07-29
+
+        ## Qt 6.10
+        utils.VersionNumber(6, 10): (_BASES[134], '140.0.7339.207'),  # 2025-09-22
+        utils.VersionNumber(6, 10, 1): (_BASES[134], '142.0.7444.162'),  # 2025-11-11
     }
 
     def __post_init__(self) -> None:
@@ -706,7 +733,7 @@ class WebEngineVersions:
     def _infer_chromium_version(
             cls,
             pyqt_webengine_version: utils.VersionNumber,
-    ) -> Tuple[Optional[str], Optional[str]]:
+    ) -> tuple[Optional[str], Optional[str]]:
         """Infer the Chromium version based on the PyQtWebEngine version.
 
         Returns:
@@ -899,6 +926,51 @@ def _backend() -> str:
     raise utils.Unreachable(objects.backend)
 
 
+def _webengine_extensions() -> Sequence[str]:
+    """Get a list of WebExtensions enabled in QtWebEngine."""
+    lines: list[str] = []
+    if (
+        objects.backend == usertypes.Backend.QtWebEngine
+        and machinery.IS_QT6  # mypy; TODO early return once Qt 5 is dropped
+    ):
+        from qutebrowser.browser.webengine import webenginesettings
+        lines.append("WebExtensions:")
+
+        if webenginesettings.default_profile:
+            profile = webenginesettings.default_profile
+        elif "avoid-chromium-init" in objects.debug_flags:
+            lines[0] += " unknown (avoiding init)"
+            return lines
+        else:
+            profile = webenginesettings.default_qt_profile()
+
+        try:
+            ext_manager = profile.extensionManager()
+        except AttributeError:
+            # Added in QtWebEngine 6.10
+            return []
+        assert ext_manager is not None  # mypy
+
+        if not ext_manager.extensions():
+            lines[0] += " none"
+
+        for info in ext_manager.extensions():
+            tags = [
+                ("[x]" if info.isEnabled() else "[ ]") + " enabled",
+                ("[x]" if info.isLoaded() else "[ ]") + " loaded",
+                ("[x]" if info.isInstalled() else "[ ]") + " installed",
+            ]
+            lines.append(f"  {info.name()} ({info.id()})")
+            lines.append(f"  {'  '.join(tags)}")
+            lines.append(f"  {info.path()}")
+            url = info.actionPopupUrl()
+            if url.isValid():
+                lines.append(f"  {url.toDisplayString()}")
+            lines.append("")
+
+    return lines
+
+
 def _uptime() -> datetime.timedelta:
     time_delta = datetime.datetime.now() - objects.qapp.launch_time
     # Round off microseconds
@@ -948,13 +1020,15 @@ def version_info() -> str:
                                      if QSslSocket.supportsSsl() else 'no'),
     ]
 
+    lines += _webengine_extensions()
+
     if objects.qapp:
         style = objects.qapp.style()
         assert style is not None
         metaobj = style.metaObject()
         assert metaobj is not None
         lines.append('Style: {}'.format(metaobj.className()))
-        lines.append('Platform plugin: {}'.format(objects.qapp.platformName()))
+        lines.append('Qt Platform: {}'.format(gui_platform_info()))
         lines.append('OpenGL: {}'.format(opengl_info()))
 
     importpath = os.path.dirname(os.path.abspath(qutebrowser.__file__))
@@ -1016,7 +1090,7 @@ class OpenGLInfo:
     version_str: Optional[str] = None
 
     # The parsed version as a (major, minor) tuple of ints
-    version: Optional[Tuple[int, ...]] = None
+    version: Optional[tuple[int, ...]] = None
 
     # The vendor specific information following the version number
     vendor_specific: Optional[str] = None
@@ -1123,6 +1197,19 @@ def opengl_info() -> Optional[OpenGLInfo]:  # pragma: no cover
             old_context.makeCurrent(old_surface)
 
 
+def gui_platform_info() -> str:
+    """Get the Qt GUI platform name, optionally with the WM/compositor name."""
+    info = objects.qapp.platformName()
+    try:
+        if info == "xcb":
+            info += f" ({wmname.x11_wm_name()})"
+        elif info in ["wayland", "wayland-egl"]:
+            info += f" ({wmname.wayland_compositor_name()})"
+    except wmname.Error as e:
+        info += f" (Error: {e})"
+    return info
+
+
 def pastebin_version(pbclient: pastebin.PastebinClient = None) -> None:
     """Pastebin the version and log the url to messages."""
     def _yank_url(url: str) -> None:
